==> haskell-yesod-test-1.6.23-75-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-test
version:              1.6.23
visibility:           public
id:                   yesod-test-1.6.23-EFAIMXXPGhjFjWWGGfMOQP
key:                  yesod-test-1.6.23-EFAIMXXPGhjFjWWGGfMOQP
license:              MIT
maintainer:           Michael Snoyman, Greg Weber, Nubis <nubis@woobiz.com.ar>
author:               Nubis <nubis@woobiz.com.ar>
stability:            Experimental
homepage:             http://www.yesodweb.com
synopsis:             integration testing for WAI/Yesod Applications
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-test>

category:             Web, Yesod, Testing
abi:                  0260365da5d58f43e6f3e3937fd66735
exposed:              True
exposed-modules:
    Yesod.Test Yesod.Test.CssQuery Yesod.Test.Internal
    Yesod.Test.Internal.SIO Yesod.Test.TransversingCSS

import-dirs:          /usr/lib/ghc-9.4.8/site-local/yesod-test-1.6.23
library-dirs:         /usr/lib/ghc-9.4.8/site-local/yesod-test-1.6.23
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/yesod-test-1.6.23
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-test
hs-libraries:         HSyesod-test-1.6.23-EFAIMXXPGhjFjWWGGfMOQP
depends:
    HUnit-1.6.2.0-DUvlqmsw2Kp6tCDRl9WtXA
    aeson-2.1.2.1-9cza8YJPY5Z8Ze3x8zf5ig
    attoparsec-0.14.4-Kqu9azGoeFY4BlHGbH5HBg base-4.17.2.1
    blaze-builder-0.4.4-IUOXk9qX0ZPB9EabAhi3MJ
    blaze-html-0.9.2.0-LlU0XfzVpg34MJkFx2EZcl
    blaze-markup-0.8.3.0-Jmy6mhQ8sFNHEauj2dm6FF bytestring-0.11.5.3
    case-insensitive-1.2.1.0-9yImpzTIYpBJ0v1fZqtWOj
    conduit-1.3.6.1-3M1B5TjJPZk646ipFSI00d containers-0.6.7
    cookie-0.4.6-4shfaVKBFn0Hnep1ZY6FZw directory-1.3.7.1
    hspec-core-2.11.0.1-7YTDqP4jJNBKUfTKWIUSEX
    html-conduit-1.3.2.2-7PypDmuvXiBb0K0DRgfWA
    http-types-0.12.4-JKUCrzdlATTa7w8tKVNt1
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt mtl-2.2.2
    network-3.1.4.0-DD61ZgteIR5Dyq0QRyt6FX
    pretty-show-1.10-Ey6CADemQl3EFi7OIHqHDp process-1.6.18.0 text-2.0.2
    time-1.12.2 transformers-0.5.6.2 wai-3.2.4-9F025KLztrGD7Hr5xRYA73
    wai-extra-3.1.17-CEHyRGVaNjy2F1ffZ5B4e0
    xml-conduit-1.9.1.4-HZKzsMGpoYKGE5hBj7zsBz
    xml-types-0.3.8-IpGyuvvNOu2AH1SOobl25
    yesod-core-1.6.27.1-Jbwti0Pu9DIIn4mS0o789w

haddock-interfaces:   /usr/share/doc/haskell-yesod-test/html/yesod-test.haddock
haddock-html:         /usr/share/doc/haskell-yesod-test/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-test-1.6.23-76-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-test
version:              1.6.23
visibility:           public
id:                   yesod-test-1.6.23-AfUPmoMHciIAnndjOSyUiA
key:                  yesod-test-1.6.23-AfUPmoMHciIAnndjOSyUiA
license:              MIT
maintainer:           Michael Snoyman, Greg Weber, Nubis <nubis@woobiz.com.ar>
author:               Nubis <nubis@woobiz.com.ar>
stability:            Experimental
homepage:             http://www.yesodweb.com
synopsis:             integration testing for WAI/Yesod Applications
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-test>

category:             Web, Yesod, Testing
abi:                  81280629309563441b86cca1f1f677cf
exposed:              True
exposed-modules:
    Yesod.Test Yesod.Test.CssQuery Yesod.Test.Internal
    Yesod.Test.Internal.SIO Yesod.Test.TransversingCSS

import-dirs:          /usr/lib/ghc-9.4.8/site-local/yesod-test-1.6.23
library-dirs:         /usr/lib/ghc-9.4.8/site-local/yesod-test-1.6.23
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/yesod-test-1.6.23
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-test
hs-libraries:         HSyesod-test-1.6.23-AfUPmoMHciIAnndjOSyUiA
depends:
    HUnit-1.6.2.0-DUvlqmsw2Kp6tCDRl9WtXA
    aeson-2.1.2.1-9cza8YJPY5Z8Ze3x8zf5ig
    attoparsec-0.14.4-Kqu9azGoeFY4BlHGbH5HBg base-4.17.2.1
    blaze-builder-0.4.4-IUOXk9qX0ZPB9EabAhi3MJ
    blaze-html-0.9.2.0-LlU0XfzVpg34MJkFx2EZcl
    blaze-markup-0.8.3.0-Jmy6mhQ8sFNHEauj2dm6FF bytestring-0.11.5.3
    case-insensitive-1.2.1.0-9yImpzTIYpBJ0v1fZqtWOj
    conduit-1.3.6.1-3M1B5TjJPZk646ipFSI00d containers-0.6.7
    cookie-0.4.6-4shfaVKBFn0Hnep1ZY6FZw directory-1.3.7.1
    hspec-core-2.11.0.1-7YTDqP4jJNBKUfTKWIUSEX
    html-conduit-1.3.2.2-7PypDmuvXiBb0K0DRgfWA
    http-types-0.12.4-JKUCrzdlATTa7w8tKVNt1
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt mtl-2.2.2
    network-3.1.4.0-DD61ZgteIR5Dyq0QRyt6FX
    pretty-show-1.10-Ey6CADemQl3EFi7OIHqHDp process-1.6.18.0 text-2.0.2
    time-1.12.2 transformers-0.5.6.2 wai-3.2.4-9F025KLztrGD7Hr5xRYA73
    wai-extra-3.1.17-CEHyRGVaNjy2F1ffZ5B4e0
    xml-conduit-1.9.1.4-HZKzsMGpoYKGE5hBj7zsBz
    xml-types-0.3.8-IpGyuvvNOu2AH1SOobl25
    yesod-core-1.6.27.1-6ZDalALPJsx6xX5KlgkPAg

haddock-interfaces:   /usr/share/doc/haskell-yesod-test/html/yesod-test.haddock
haddock-html:         /usr/share/doc/haskell-yesod-test/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
